/*
 * System Interface Library for games
 * Copyright (c) 2007-2017 Andrew Church <achurch@achurch.org>
 * Released under the GNU GPL version 3 or later; NO WARRANTY is provided.
 * See the file COPYING.txt for details.
 *
 * src/sysdep/test/time.c: Testing implementation of the system-level
 * timekeeping functions.
 */

/*
 * This file implements an overlay of the sys_time_*() functions for
 * testing time-related functionality.  The "current time" reported by
 * sys_time_now() can be set arbitrarily by calling sys_test_time_set().
 */

#define IN_SYSDEP_TEST

#include "src/base.h"
#include "src/math.h"
#include "src/sysdep.h"
#include "src/sysdep/test.h"

/*************************************************************************/
/****************************** Local data *******************************/
/*************************************************************************/

#define TIME_UNITS_PER_SEC  64

static uint64_t current_time;  // Current time reported by sys_time_now().

/*************************************************************************/
/************************** Interface routines ***************************/
/*************************************************************************/

void sys_time_init(void)
{
    current_time = 0;
}

/*-----------------------------------------------------------------------*/

int sys_time_unit(void)
{
    return TIME_UNITS_PER_SEC;
}

/*-----------------------------------------------------------------------*/

uint64_t sys_time_now(void)
{
    return current_time;
}

/*-----------------------------------------------------------------------*/

void sys_time_delay(int64_t time)
{
    current_time += time;
}

/*************************************************************************/
/************************* Test control routines *************************/
/*************************************************************************/

void sys_test_time_set(uint64_t time)
{
    current_time = time;
}

/*-----------------------------------------------------------------------*/

void sys_test_time_set_seconds(double time)
{
    current_time = (uint64_t)(time * TIME_UNITS_PER_SEC);
}

/*************************************************************************/
/*************************************************************************/

/*
 * Local variables:
 *   c-file-style: "stroustrup"
 *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
 *   indent-tabs-mode: nil
 * End:
 *
 * vim: expandtab shiftwidth=4:
 */
